# MkDocs Zettelkasten

This is a [Zettelkasten](https://zettelkasten.de) theme and plugin for [MkDocs](https://www.mkdocs.org). It renders the MkDocs pages as cards (zettels).

For more information, head on over to [the documentation](https://buvis.github.io/mkdocs-zettelkasten/)

## Development

### Update

1. Update dependencies: `make update`
2. Increment version in `setup.py`
3. Test: `make test`
4. Build: `make build`
5. Check if compliant with PyPI: `make check`
6. Publish the new version to PyPI: `make publish`
